@@ -5,6 +5,7 @@ from pymodelextractor.tests.learners_tests.test_kearns_vazirani_learner import T
 from pymodelextractor.tests.learners_tests.test_pdfa_lstar_learner import TestPDFALStarLearner
 from pymodelextractor.tests.learners_tests.test_pdfa_lstarcol_learner import TestPDFALStarColLearner
 from tests.learners_tests.test_lambda_star_learner import TestLambdaStarLearnerWithEqualityAlgebra
+from tests.learners_tests.test_pdfa_teachers import TestPDFATeachers
 
 
 def run():
@@ -12,7 +13,8 @@ def run():
                            TestPDFALStarLearner,
                            TestKearnsVaziraniLearner,
                            TestLStarLearner,
-                           TestPDFALStarColLearner]
+                           TestPDFALStarColLearner,
+                           TestPDFATeachers]
     loader = TestLoader()
     suites_list = []
     for test_class in test_classes_to_run:
